def add(a, b):
    return(a + b)
def multiply(a, b):
    return(a * b)
def divide(a, b):
    return(a/b)
def subtract(a, b):
    return(a - b )
def floor_division(a, b):
    return(a //b)
def modulus(a, b):
    return(a % b)
def si(a,b,c):
    return ((a*b*c)/100)
def ci(p, r, t):
    return (p*((r/100+1)**t))-p